# wavy

[![Tests (python)](https://github.com/bohlinger/wavy/actions/workflows/python.yml/badge.svg)](https://github.com/bohlinger/wavy/actions/workflows/python.yml)
[![Lint](https://github.com/bohlinger/wavy/actions/workflows/lint.yml/badge.svg)](https://github.com/bohlinger/wavy/actions/workflows/lint.yml)
[![Coverage Status](https://coveralls.io/repos/github/bohlinger/wavy/badge.svg?branch=master)](https://coveralls.io/github/bohlinger/wavy?branch=master)
[![Documentation Status](https://readthedocs.org/projects/wavyopen/badge/?version=latest)](https://wavyopen.readthedocs.io/en/latest/?badge=latest)

### Main developer and moderation:
Patrik Bohlinger, Norwegian Meteorological Institute, patrikb@met.no

## Purpose
Package to aid the collocation of observations and wave model output as well as subsequent wave model validation and calibration. Observational sources can be satellite altimetry or in-situ data. A variety of open source alternatives is implemented.

## Docs
For more information about the package as well as documentation please refer to the [documentation](https://wavyopen.readthedocs.io/en/latest/index.html).

## Credits
When using **wavy** please give credit by citing:
[Bohlinger et al. 2019](https://doi.org/10.1016/j.ocemod.2019.101404)
